@@ -110,7 +110,7 @@ class HttpFD(FileDownloader):
         # However, for a test we still would like to download just a piece of a file.
         # To achieve this we limit data_len to _TEST_FILE_SIZE and manually control
         # block size when downloading a file.
-        if is_test and data_len > self._TEST_FILE_SIZE:
+        if is_test and (data_len is None or int(data_len) > self._TEST_FILE_SIZE):
             data_len = self._TEST_FILE_SIZE
 
         if data_len is not None:
